@@ -1,15 +1,15 @@
 /*
  * Project       : ipv6calc
  * File          : dbieee_oui36.h
- * Version       : $Id: dbieee_oui36.h,v 1.15 2014/07/14 06:20:02 ds6peter Exp $
- * Generated     : Mon Jul 14 08:12:47 2014
+ * Version       : $Id: dbieee_oui36.h,v 1.16 2014/07/31 18:39:42 ds6peter Exp $
+ * Generated     : Thu Jul 31 20:34:26 2014
  * Data copyright: IEEE
  *
  * Information:
  *  Additional header file for libipv6calc_db_wrapper_BuiltIn.c
  */
 
-/*@unused@*/ static const char* libieee_oui36_status __attribute__ ((__unused__)) = "OUI36/20140714";
+/*@unused@*/ static const char* libieee_oui36_status __attribute__ ((__unused__)) = "OUI36/20140731";
 
 
 static const s_ieee_oui36 libieee_oui36[] = {
@@ -215,59 +215,79 @@ static const s_ieee_oui36 libieee_oui36[] = {
 	{ 0x001BC5, 0x0C8000, 0x0C8FFF, "Dialine", "DIALINE" },
 	{ 0x001BC5, 0x0C9000, 0x0C9FFF, "UAB Kitron", "UAB-KITRON" },
 	{ 0x70B3D5, 0xFFE000, 0xFFEFFF, "PRIVATE", "PRIVATE" },
-	{ 0x70B3D5, 0x062000, 0x062FFF, "RM Michaelides Software & Elektronik GmbH", "RM-MICHAELIDES-SOFTWARE-ELEKTRONIK" },
-	{ 0x70B3D5, 0xFFF000, 0xFFFFFF, "PRIVATE", "PRIVATE" },
 	{ 0x70B3D5, 0xE58000, 0xE58FFF, "Thurlby Thandar Instruments LTD", "THURLBY-THANDAR-INSTRUMENTS" },
-	{ 0x70B3D5, 0xD9E000, 0xD9EFFF, "GRUPO EPELSA S.L.", "GRUPO-EPELSA-S-L" },
+	{ 0x70B3D5, 0xFFF000, 0xFFFFFF, "PRIVATE", "PRIVATE" },
 	{ 0x70B3D5, 0xCE7000, 0xCE7FFF, "June Automation Singapore Pte. Ltd.", "JUNE-AUTOMATION-SINGAPORE-PTE" },
-	{ 0x70B3D5, 0x3DE000, 0x3DEFFF, "ELOMAC Elektronik GmbH", "ELOMAC-ELEKTRONIK" },
+	{ 0x70B3D5, 0xD9E000, 0xD9EFFF, "GRUPO EPELSA S.L.", "GRUPO-EPELSA-S-L" },
 	{ 0x70B3D5, 0x182000, 0x182FFF, "Kitron UAB", "KITRON-UAB" },
-	{ 0x70B3D5, 0xB3D000, 0xB3DFFF, "Inras GmbH", "INRAS" },
+	{ 0x70B3D5, 0x3DE000, 0x3DEFFF, "ELOMAC Elektronik GmbH", "ELOMAC-ELEKTRONIK" },
 	{ 0x70B3D5, 0x6F3000, 0x6F3FFF, "iungo", "IUNGO" },
-	{ 0x70B3D5, 0xEDC000, 0xEDCFFF, "J.D. Koftinoff Software, Ltd.", "J-D-KOFTINOFF-SOFTWARE" },
+	{ 0x70B3D5, 0xB3D000, 0xB3DFFF, "Inras GmbH", "INRAS" },
 	{ 0x70B3D5, 0x5EA000, 0x5EAFFF, "KYS,INC", "KYS" },
-	{ 0x70B3D5, 0xEF9000, 0xEF9FFF, "Critical Link", "CRITICAL-LINK" },
+	{ 0x70B3D5, 0xEDC000, 0xEDCFFF, "J.D. Koftinoff Software, Ltd.", "J-D-KOFTINOFF-SOFTWARE" },
 	{ 0x70B3D5, 0xC61000, 0xC61FFF, "JC HUNTER TECHNOLOGIES", "JC-HUNTER-TECHNOLOGIES" },
-	{ 0x70B3D5, 0xEDD000, 0xEDDFFF, "Solar Network & Partners", "SOLAR-NETWORK-PARTNERS" },
+	{ 0x70B3D5, 0xEF9000, 0xEF9FFF, "Critical Link", "CRITICAL-LINK" },
 	{ 0x70B3D5, 0x48D000, 0x48DFFF, "OMEGA BILANCE SRL SOCIETA' UNIPERSONALE", "OMEGA-BILANCE-SRL-SOCIETA-UNIPERSONALE" },
-	{ 0x70B3D5, 0xF62000, 0xF62FFF, "FRS GmbH & Co. KG", "FRS" },
+	{ 0x70B3D5, 0xEDD000, 0xEDDFFF, "Solar Network & Partners", "SOLAR-NETWORK-PARTNERS" },
 	{ 0x70B3D5, 0xB82000, 0xB82FFF, "Lookout Portable Security", "LOOKOUT-PORTABLE-SECURITY" },
-	{ 0x70B3D5, 0x0A9000, 0x0A9FFF, "ProConnections, Inc.", "PROCONNECTIONS" },
+	{ 0x70B3D5, 0xF62000, 0xF62FFF, "FRS GmbH & Co. KG", "FRS" },
 	{ 0x70B3D5, 0x220000, 0x220FFF, "PRIVATE", "PRIVATE" },
-	{ 0x70B3D5, 0x3ED000, 0x3EDFFF, "Ultra Electronics Sonar System Division", "ULTRA-ELECTRONICS-SONAR-SYSTEM-DIVISION" },
+	{ 0x70B3D5, 0x0A9000, 0x0A9FFF, "ProConnections, Inc.", "PROCONNECTIONS" },
 	{ 0x70B3D5, 0xE28000, 0xE28FFF, "iotec GmbH", "IOTEC" },
-	{ 0x70B3D5, 0x3C2000, 0x3C2FFF, "Cellular Specialties, Inc.", "CELLULAR-SPECIALTIES" },
+	{ 0x70B3D5, 0x3ED000, 0x3EDFFF, "Ultra Electronics Sonar System Division", "ULTRA-ELECTRONICS-SONAR-SYSTEM-DIVISION" },
 	{ 0x70B3D5, 0xA5B000, 0xA5BFFF, "Christ Elektronik GmbH", "CHRIST-ELEKTRONIK" },
-	{ 0x70B3D5, 0xD8B000, 0xD8BFFF, "Lenoxi Automation s.r.o.", "LENOXI-AUTOMATION-S-R-O" },
+	{ 0x70B3D5, 0x3C2000, 0x3C2FFF, "Cellular Specialties, Inc.", "CELLULAR-SPECIALTIES" },
 	{ 0x70B3D5, 0x39A000, 0x39AFFF, "Videotrend srl", "VIDEOTREND-SRL" },
-	{ 0x70B3D5, 0xF63000, 0xF63FFF, "Ars Products", "ARS-PRODUCTS" },
+	{ 0x70B3D5, 0xD8B000, 0xD8BFFF, "Lenoxi Automation s.r.o.", "LENOXI-AUTOMATION-S-R-O" },
 	{ 0x70B3D5, 0x104000, 0x104FFF, "Plum sp. z o.o", "PLUM-SP-Z-O-O" },
-	{ 0x70B3D5, 0x0AA000, 0x0AAFFF, "Wanco Inc", "WANCO" },
+	{ 0x70B3D5, 0xF63000, 0xF63FFF, "Ars Products", "ARS-PRODUCTS" },
 	{ 0x70B3D5, 0xB8D000, 0xB8DFFF, "JungwooEng Co., Ltd", "JUNGWOOENG" },
-	{ 0x70B3D5, 0x994000, 0x994FFF, "KeFF Networks", "KEFF-NETWORKS" },
+	{ 0x70B3D5, 0x0AA000, 0x0AAFFF, "Wanco Inc", "WANCO" },
 	{ 0x70B3D5, 0xCFF000, 0xCFFFFF, "DTECH Labs, Inc.", "DTECH-LABS" },
-	{ 0x70B3D5, 0x0E0000, 0x0E0FFF, "PLCiS", "PLCIS" },
+	{ 0x70B3D5, 0x994000, 0x994FFF, "KeFF Networks", "KEFF-NETWORKS" },
 	{ 0x70B3D5, 0x959000, 0x959FFF, "Zulex International Co.,Ltd.", "ZULEX" },
+	{ 0x70B3D5, 0x0E0000, 0x0E0FFF, "PLCiS", "PLCIS" },
+	{ 0x70B3D5, 0xFDE000, 0xFDEFFF, "AERONAUTICAL & GENERAL INSTRUMENTS LTD.", "AERONAUTICAL-GENERAL-INSTRUMENTS" },
 	{ 0x70B3D5, 0xAE9000, 0xAE9FFF, "Cari Electronic", "CARI" },
+	{ 0x70B3D5, 0x1A1000, 0x1A1FFF, "HMicro Inc", "HMICRO" },
 	{ 0x70B3D5, 0x6D3000, 0x6D3FFF, "DEUTA-WERKE GmbH", "DEUTA-WERKE" },
+	{ 0x70B3D5, 0x76E000, 0x76EFFF, "Grupo Epelsa S.L.", "GRUPO-EPELSA-S-L" },
 	{ 0x70B3D5, 0x139000, 0x139FFF, "Tunstall A/S", "TUNSTALL-A/S" },
+	{ 0x70B3D5, 0x882000, 0x882FFF, "SIMON TECH, S.L.", "SIMON-TECH-S-L" },
 	{ 0x70B3D5, 0x908000, 0x908FFF, "Accusonic", "ACCUSONIC" },
+	{ 0x70B3D5, 0x35D000, 0x35DFFF, "Fresh Idea Factory BV", "FRESH-IDEA-FACTORY" },
 	{ 0x70B3D5, 0x871000, 0x871FFF, "Oso Technologies", "OSO-TECHNOLOGIES" },
+	{ 0x70B3D5, 0x344000, 0x344FFF, "IHI Inspection & Instrumentation Co., Ltd.", "IHI-INSPECTION-INSTRUMENTATION" },
 	{ 0x70B3D5, 0x814000, 0x814FFF, "Ingenieurbuero SOMTRONIK", "INGENIEURBUERO-SOMTRONIK" },
+	{ 0x70B3D5, 0xB7E000, 0xB7EFFF, "Elbit Systems of America - FMF Operations", "ELBIT-OF-AMERICA---FMF-OPERATIONS" },
 	{ 0x70B3D5, 0x183000, 0x183FFF, "Evco S.p.a.", "EVCO-S-P-A" },
+	{ 0x70B3D5, 0x092000, 0x092FFF, "inomed Medizintechnik GmbH", "INOMED-MEDIZINTECHNIK" },
 	{ 0x70B3D5, 0x28F000, 0x28FFFF, "Overline Systems", "OVERLINE" },
+	{ 0x70B3D5, 0x6F8000, 0x6F8FFF, "SENSEON Corporation", "SENSEON" },
 	{ 0x70B3D5, 0x6B6000, 0x6B6FFF, "INRADIOS GmbH", "INRADIOS" },
+	{ 0x70B3D5, 0xD3B000, 0xD3BFFF, "NimbeLink Corp", "NIMBELINK" },
 	{ 0x70B3D5, 0x29D000, 0x29DFFF, "XTech2 SIA", "XTECH2-SIA" },
+	{ 0x70B3D5, 0x84A000, 0x84AFFF, "MOG Laboratories Pty Ltd", "MOG-LABORATORIES-PTY" },
 	{ 0x70B3D5, 0x109000, 0x109FFF, "DiTEST Fahrzeugdiagnose GmbH", "DITEST-FAHRZEUGDIAGNOSE" },
+	{ 0x70B3D5, 0x9F5000, 0x9F5FFF, "Vickers Electronics Ltd", "VICKERS-ELECTRONICS" },
 	{ 0x70B3D5, 0x184000, 0x184FFF, "XV360 Optical Information Systems Ltd.", "XV360-OPTICAL-INFORMATION" },
+	{ 0x70B3D5, 0xD0C000, 0xD0CFFF, "Connor Winfield LTD", "CONNOR-WINFIELD" },
 	{ 0x70B3D5, 0x35C000, 0x35CFFF, "ACS electronics srl", "ACS-ELECTRONICS-SRL" },
+	{ 0x70B3D5, 0x7CD000, 0x7CDFFF, "Molekuler Goruntuleme A.S.", "MOLEKULER-GORUNTULEME-A-S" },
 	{ 0x70B3D5, 0x40A000, 0x40AFFF, "Monroe Electronics, Inc.", "MONROE-ELECTRONICS" },
+	{ 0x70B3D5, 0x1F4000, 0x1F4FFF, "Hangzhou Woosiyuan Communication Co.,Ltd.", "HANGZHOU-WOOSIYUAN-COMMUNICATION" },
 	{ 0x70B3D5, 0x190000, 0x190FFF, "Fantom Wireless, Inc.", "FANTOM-WIRELESS" },
+	{ 0x70B3D5, 0xDE7000, 0xDE7FFF, "Innominds Software Private Limited", "INNOMINDS-SOFTWARE-PRIVATE" },
 	{ 0x70B3D5, 0x308000, 0x308FFF, "DSD MICROTECHNOLOGY,INC.", "DSD-MICROTECHNOLOGY" },
+	{ 0x70B3D5, 0x2D5000, 0x2D5FFF, "Teuco Guzzini", "TEUCO-GUZZINI" },
 	{ 0x70B3D5, 0x9F4000, 0x9F4FFF, "Tband srl", "TBAND-SRL" },
+	{ 0x70B3D5, 0x44B000, 0x44BFFF, "Open System Solutions Limited", "OPEN-SYSTEM-SOLUTIONS" },
 	{ 0x70B3D5, 0xECD000, 0xECDFFF, "SBS-Feintechnik GmbH & Co. KG", "SBS-FEINTECHNIK" },
+	{ 0x70B3D5, 0xFF5000, 0xFF5FFF, "Prolan Process Control Co.", "PROLAN-PROCESS-CONTROL" },
 	{ 0x70B3D5, 0x918000, 0x918FFF, "Glova Rail A/S", "GLOVA-RAIL-A/S" },
+	{ 0x70B3D5, 0xE75000, 0xE75FFF, "Nke", "NKE" },
 	{ 0x70B3D5, 0x42F000, 0x42FFFF, "SINTOKOGIO, LTD", "SINTOKOGIO" },
+	{ 0x70B3D5, 0x030000, 0x030FFF, "Tresent Technologies", "TRESENT-TECHNOLOGIES" },
 	{ 0x70B3D5, 0xC8D000, 0xC8DFFF, "KST Technology", "KST" },
 	{ 0x70B3D5, 0x702000, 0x702FFF, "Sensor Highway Ltd", "SENSOR-HIGHWAY" },
 	{ 0x70B3D5, 0x044000, 0x044FFF, "Don Electronics Ltd", "DON-ELECTRONICS" },
@@ -485,7 +505,7 @@ static const s_ieee_oui36 libieee_oui36[] = {
 	{ 0x70B3D5, 0xEC1000, 0xEC1FFF, "Xafax Nederland bv", "XAFAX-NEDERLAND" },
 	{ 0x70B3D5, 0x0FF000, 0x0FFFFF, "INTERNET PROTOCOLO LOGICA SL", "INTERNET-PROTOCOLO-LOGICA-SL" },
 	{ 0x70B3D5, 0x7B3000, 0x7B3FFF, "BroadSoft Inc", "BROADSOFT" },
-	{ 0x70B3D5, 0x7D5000, 0x7D5FFF, "Power Dragon Development Limited", "POWER-DRAGON-DEVELOPMENT" },
 	{ 0x70B3D5, 0x0AB000, 0x0ABFFF, "KST technology", "KST" },
+	{ 0x70B3D5, 0x062000, 0x062FFF, "RM Michaelides Software & Elektronik GmbH", "RM-MICHAELIDES-SOFTWARE-ELEKTRONIK" },
 
 };
