@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_GeoIP.c
- * Version    : $Id: libipv6calc_db_wrapper_GeoIP.c,v 1.60 2014/06/22 09:49:25 ds6peter Exp $
+ * Version    : $Id: libipv6calc_db_wrapper_GeoIP.c,v 1.66 2014/07/30 20:31:43 ds6peter Exp $
  * Copyright  : 2013-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -202,7 +202,9 @@ int libipv6calc_db_wrapper_GeoIP_wrapper_init(void) {
 	dl_GeoIP_handle = dlopen(geoip_lib_file, RTLD_NOW | RTLD_LOCAL);
 
 	if (dl_GeoIP_handle == NULL) {
-		fprintf(stderr, "GeoIP dynamic library load failed: %s\n", dlerror());
+		if ((strcmp(geoip_lib_file, GEOIP_DYN_LIB) != 0) || (ipv6calc_verbose > 0)) {
+			NONQUIETPRINT_WA("GeoIP dynamic library load failed (disable support): %s", dlerror())
+		};
 		return(1);
 	};
 
@@ -343,41 +345,48 @@ int libipv6calc_db_wrapper_GeoIP_wrapper_init(void) {
 	if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_COUNTRY_EDITION) == 1) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_COUNTRY_EDITION available");
 		geoip_country_v4 = 1;
-		wrapper_features_GeoIP |= IPV6CALC_DB_IPV4_TO_CC;
+		wrapper_features_GeoIP |= IPV6CALC_DB_IPV4_TO_CC | IPV6CALC_DB_GEOIP_IPV4;
 	};
 
 #ifdef SUPPORT_GEOIP_V6
 	if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_COUNTRY_EDITION_V6) == 1) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_COUNTRY_EDITION_V6 available");
 		geoip_country_v6 = 1;
-		wrapper_features_GeoIP |= IPV6CALC_DB_IPV6_TO_CC;
+		wrapper_features_GeoIP |= IPV6CALC_DB_IPV6_TO_CC | IPV6CALC_DB_GEOIP_IPV6;
 	};
 #endif
 
 	if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_ASNUM_EDITION) == 1) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_ASNUM_EDITION available");
 		geoip_asnum_v4 = 1;
-		wrapper_features_GeoIP |= IPV6CALC_DB_IPV4_TO_AS;
+		wrapper_features_GeoIP |= IPV6CALC_DB_IPV4_TO_AS | IPV6CALC_DB_GEOIP_IPV4;
 	};
 
-	if ((lib_features_GeoIP & (GEOIP_LIB_FEATURE_IPV6_CC_BY_ADDR | GEOIP_LIB_FEATURE_IPV6_CC_BY_ADDR)) != 0) {
-#ifdef GEOIP_ASNUM_EDITION_V6
+	if ((lib_features_GeoIP & (GEOIP_LIB_FEATURE_IPV6_CC_BY_ADDR | GEOIP_LIB_FEATURE_IPV6_CN_BY_ADDR)) != 0) {
+#if HAVE_DECL_GEOIP_ASNUM_EDITION_V6 == 1
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP check for GEOIP_ASNUM_EDITION_V6 & GEOIP_CITY_EDITION_REV1_V6");
 		if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_ASNUM_EDITION_V6) == 1) {
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_ASNUM_EDITION_V6 available");
 			geoip_asnum_v6 = 1;
-			wrapper_features_GeoIP |= IPV6CALC_DB_IPV6_TO_AS;
+			wrapper_features_GeoIP |= IPV6CALC_DB_IPV6_TO_AS | IPV6CALC_DB_GEOIP_IPV6;
 		};
 
 		if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_CITY_EDITION_REV1_V6) == 1) {
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_CITY_EDITION_REV1_V6 available");
 			geoip_city_v6 = 1;
+			wrapper_features_GeoIP |= IPV6CALC_DB_GEOIP_IPV6;
 		};
+#else
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP check skipped for GEOIP_ASNUM_EDITION_V6 & GEOIP_CITY_EDITION_REV1_V6");
 #endif
+	} else {
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP library looks like missing features for GEOIP_ASNUM_EDITION_V6 & GEOIP_CITY_EDITION_REV1_V6");
 	};
 
 	if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_CITY_EDITION_REV1) == 1) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_CITY_EDITION_REV1 available");
 		geoip_city_v4 = 1;
+		wrapper_features_GeoIP |= IPV6CALC_DB_GEOIP_IPV4;
 	};
 
 	wrapper_features |= wrapper_features_GeoIP;
@@ -461,13 +470,13 @@ void libipv6calc_db_wrapper_GeoIP_wrapper_print_db_info(const int level_verbose,
 			if (gi == NULL) {
 				if (i == GEOIP_CITY_EDITION_REV0) { continue; };
 
-#ifdef GEOIP_LARGE_COUNTRY_EDITION
+#if HAVE_DECL_GEOIP_LARGE_COUNTRY_EDITION == 1
 				if (i == GEOIP_LARGE_COUNTRY_EDITION) { continue; };
 #endif
-#ifdef GEOIP_CITY_EDITION_REV0_V6
+#if HAVE_DECL_GEOIP_CITY_EDITION_REV0_V6 == 1
 				if (i == GEOIP_CITY_EDITION_REV0_V6) { continue; };
 #endif
-#ifdef GEOIP_LARGE_COUNTRY_EDITION_V6
+#if HAVE_DECL_GEOIP_LARGE_COUNTRY_EDITION_V6 == 1
 				if (i == GEOIP_LARGE_COUNTRY_EDITION_V6) { continue; };
 #endif
 
@@ -501,7 +510,7 @@ void libipv6calc_db_wrapper_GeoIP_wrapper_print_db_info(const int level_verbose,
 #endif
 
 	if (count == 0) {
-		printf("%sGeoIP: NO available databases found in directory: %s\n", prefix, geoip_db_dir);
+		printf("%sGeoIP: No available databases found in directory: %s\n", prefix, geoip_db_dir);
 	};
 
 #else
@@ -1958,7 +1967,7 @@ char *libipv6calc_db_wrapper_GeoIP_wrapper_asnum_by_addr(const char *addr, const
 			return(NULL);
 		};
 
-#ifdef GEOIP_ASNUM_EDITION
+#if HAVE_DECL_GEOIP_ASNUM_EDITION == 1
 		GeoIP_type = GEOIP_ASNUM_EDITION;
 #else
 		return(NULL);
@@ -1971,7 +1980,7 @@ char *libipv6calc_db_wrapper_GeoIP_wrapper_asnum_by_addr(const char *addr, const
 			return(NULL);
 		};
 
-#ifdef GEOIP_ASNUM_EDITION_V6
+#if HAVE_DECL_GEOIP_ASNUM_EDITION_V6 == 1
 		GeoIP_type = GEOIP_ASNUM_EDITION_V6;
 #else
 		return(NULL);
@@ -2021,7 +2030,7 @@ GeoIPRecord *libipv6calc_db_wrapper_GeoIP_wrapper_record_city_by_addr(const char
 #ifdef SUPPORT_GEOIP_V6
 	} else if (proto == 6) {
 		if ((lib_features_GeoIP & GEOIP_LIB_FEATURE_LIB_VERSION) != 0) {
-#ifdef GEOIP_CITY_EDITION_REV1_V6
+#if HAVE_DECL_GEOIP_CITY_EDITION_REV1_V6 == 1
 			GeoIP_type = GEOIP_CITY_EDITION_REV1_V6;
 #else
 			return (NULL);
