@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_IP2Location.c
- * Version    : $Id: libipv6calc_db_wrapper_IP2Location.c,v 1.16 2014/05/16 20:34:02 ds6peter Exp $
+ * Version    : $Id: libipv6calc_db_wrapper_IP2Location.c,v 1.19 2014/07/31 06:20:35 ds6peter Exp $
  * Copyright  : 2013-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -86,8 +86,6 @@ static int wrapper_ip2location_ipv6_support = IP2LOCATION_IPV6_SUPPORT_UNKNOWN;
 #endif
 #endif // SUPPORT_IP2LOCATION_DYN
 
-static int ip2location_country_v4 = 0;
-static int ip2location_country_v6 = 0;
 static int ip2location_asnum_v4 = 0;
 static int ip2location_asnum_v6 = 0;
 static int ip2location_city_v4 = 0;
@@ -134,7 +132,9 @@ int libipv6calc_db_wrapper_IP2Location_wrapper_init(void) {
 	dl_IP2Location_handle = dlopen(ip2location_lib_file, RTLD_NOW | RTLD_LOCAL);
 
 	if (dl_IP2Location_handle == NULL) {
-		NONQUIETPRINT_WA("IP2Location dynamic library load failed: %s", dlerror());
+		if ((strcmp(ip2location_lib_file, IP2LOCATION_DYN_LIB) != 0) || (ipv6calc_verbose > 0)) {
+			NONQUIETPRINT_WA("IP2Location dynamic library load failed (disable support): %s", dlerror());
+		};
 		return(1);
 	};
 
@@ -198,7 +198,7 @@ void libipv6calc_db_wrapper_IP2Location_wrapper_info(char* string, const size_t
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Called");
 
 #ifdef SUPPORT_IP2LOCATION
-	snprintf(string, size, "IP2Location available databases: Country4=%d Country6=%d ASN4=%d ASN6=%d City4=%d City6=%d", ip2location_country_v4, ip2location_country_v6, ip2location_asnum_v4, ip2location_asnum_v6, ip2location_city_v4, ip2location_city_v6);
+	snprintf(string, size, "IP2Location available databases: Country4=%d Country6=%d ASN4=%d ASN6=%d City4=%d City6=%d", (wrapper_features & IPV6CALC_DB_IPV4_TO_CC) ? 1 : 0, (wrapper_features & IPV6CALC_DB_IPV6_TO_CC) ? 1 : 0, ip2location_asnum_v4, ip2location_asnum_v6, ip2location_city_v4, ip2location_city_v6);
 #else
 	snprintf(string, size, "No IP2Location support built-in");
 #endif
