@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calc/ipv6calc.c
- * Version    : $Id: ipv6calc.c,v 1.111 2014/05/11 09:49:38 ds6peter Exp $
+ * Version    : $Id: ipv6calc.c,v 1.113 2014/07/22 06:00:41 ds6peter Exp $
  * Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
@@ -584,6 +584,11 @@ int main(int argc, char *argv[]) {
 		} else {
 			printversion();
 		};
+
+		if ((command & CMD_printhelp) != 0) {
+			printversion_help();
+		};
+
 		exit(EXIT_SUCCESS);
 	};
 
