@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : showinfo.c
- * Version    : $Id: showinfo.c,v 1.111 2014/05/11 09:49:38 ds6peter Exp $
+ * Version    : $Id: showinfo.c,v 1.116 2014/07/31 06:20:35 ds6peter Exp $
  * Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
@@ -121,6 +121,7 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, " IPV6CALC_COPYRIGHT=\"...\"      : Copyright string\n");
 	fprintf(stderr, " IPV6CALC_OUTPUT_VERSION=x     : Version of output format\n");
 	fprintf(stderr, " IPV6CALC_FEATURES=\"...\"       : Feature string of ipv6calc -v\n");
+	fprintf(stderr, " IPV6CALC_CAPABILITIES=\"...\"   : Capability string of ipv6calc -v -v\n");
 	fprintf(stderr, " IPV6CALC_SETTINGS_ANON=\"...\"  : Anonymizer settings\n");
 };
 
@@ -138,7 +139,6 @@ static void printout(const char *string) {
 static void printfooter(const uint32_t formatoptions) {
 	char tempstring[NI_MAXHOST] = "";
 	char tempstring2[NI_MAXHOST] = "";
-	int i;
 
 #if defined SUPPORT_IP2LOCATION || defined SUPPORT_GEOIP
 	char *string;
@@ -174,62 +174,37 @@ static void printfooter(const uint32_t formatoptions) {
 		snprintf(tempstring, sizeof(tempstring), "IPV6CALC_SETTINGS_ANON=\"%s\"", tempstring2);
 		printout(tempstring);
 
+		/* features */
 		tempstring[0] = '\0'; /* clear tempstring */
 
-#ifdef SUPPORT_IP2LOCATION
-#ifdef SUPPORT_IP2LOCATION_DYN
-		snprintf(tempstring2, sizeof(tempstring2), "%s IP2Location(dyn-load)", tempstring);
-#else
-#ifdef SUPPORT_IP2LOCATION_STATIC
-		snprintf(tempstring2, sizeof(tempstring2), "%s IP2Location(static)", tempstring);
-#else
-		snprintf(tempstring2, sizeof(tempstring2), "%s IP2Location", tempstring);
-#endif
-#endif
-		snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
-#endif
-
-#ifdef SUPPORT_GEOIP
-#ifdef SUPPORT_GEOIP_DYN
-		snprintf(tempstring2, sizeof(tempstring2), "%s GeoIP(dyn-load)", tempstring);
-#else
-#ifdef SUPPORT_GEOIP_STATIC
-		snprintf(tempstring2, sizeof(tempstring2), "%s GeoIP(static)", tempstring);
-#else
-		snprintf(tempstring2, sizeof(tempstring2), "%s GeoIP", tempstring);
-#endif
-#endif
-		snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
-#ifdef SUPPORT_GEOIP_V6
-		snprintf(tempstring2, sizeof(tempstring2), "%s GeoIPv6", tempstring);
-		snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
-#endif
-#endif
+		libipv6calc_db_wrapper_features(tempstring, sizeof(tempstring));
 
 		if (feature_zeroize == 1) {
-			snprintf(tempstring2, sizeof(tempstring2), "%s ANON_ZEROISE", tempstring);
+			snprintf(tempstring2, sizeof(tempstring2), "%s%sANON_ZEROISE", tempstring, strlen(tempstring) > 0 ? " " : "");
 			snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
 		};
 
 		if (feature_anon == 1) {
-			snprintf(tempstring2, sizeof(tempstring2), "%s ANON_ANONYMIZE", tempstring);
+			snprintf(tempstring2, sizeof(tempstring2), "%s%sANON_ANONYMIZE", tempstring, strlen(tempstring) > 0 ? " " : "");
 			snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
 		};
 
 		if (feature_kp == 1) {
-			snprintf(tempstring2, sizeof(tempstring2), "%s ANON_KEEP-TYPE-ASN-CC", tempstring);
+			snprintf(tempstring2, sizeof(tempstring2), "%s%sANON_KEEP-TYPE-ASN-CC", tempstring, strlen(tempstring) > 0 ? " " : "");
 			snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
 		};
 
-		/* cut off first char */
-		for (i = 0; i < strlen(tempstring); i++) {
-			tempstring[i] = tempstring[i+1];
-		};
-
-		libipv6calc_db_wrapper_features(tempstring, sizeof(tempstring));
 	
 		snprintf(tempstring2, sizeof(tempstring2), "IPV6CALC_FEATURES=\"%s\"", tempstring);
 		printout(tempstring2);
+
+		/* capabilities */
+		tempstring[0] = '\0'; /* clear tempstring */
+
+		libipv6calc_db_wrapper_capabilities(tempstring, sizeof(tempstring));
+
+		snprintf(tempstring2, sizeof(tempstring2), "IPV6CALC_CAPABILITIES=\"%s\"", tempstring);
+		printout(tempstring2);
 	};
 };
 
@@ -541,7 +516,12 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		};
 		printout(tempstring);
 	} else {
-		fprintf(stdout, "IPv4 address: %s\n", tempipv4string);
+
+		if ((string != NULL) && (strlen(string) > 0)) {
+			fprintf(stdout, "IPv4 address: %s (%s)\n", tempipv4string, string);
+		} else {
+			fprintf(stdout, "IPv4 address: %s\n", tempipv4string);
+		};
 
 		fprintf(stdout, "IPv4 address type: ");
 		j = 0;
@@ -555,43 +535,45 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		fprintf(stdout, "\n");
 	};	
 
-	/* get AS Information */
-	as_num32 = libipv4addr_as_num32_by_addr(ipv4addrp);
-	if ((typeinfo & IPV4_ADDR_ANONYMIZED) == 0) {
-		if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_AS) == 1) {
-			as_text = libipv6calc_db_wrapper_as_text_by_addr(tempipv4string, 4);
+	if ((typeinfo & (IPV4_ADDR_GLOBAL)) != 0) {
+		/* get AS Information */
+		as_num32 = libipv4addr_as_num32_by_addr(ipv4addrp);
+		if ((typeinfo & IPV4_ADDR_ANONYMIZED) == 0) {
+			if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_AS) == 1) {
+				as_text = libipv6calc_db_wrapper_as_text_by_addr(tempipv4string, 4);
+			};
 		};
-	};
 
-	if (as_num32 != ASNUM_AS_UNKNOWN) {
-		if ( machinereadable != 0 ) {
-			snprintf(tempstring, sizeof(tempstring), "IPV4_AS_NUM%s=%d", embeddedipv4string, as_num32);
-			printout(tempstring);
-
-			if (as_text != NULL) {
-				snprintf(tempstring, sizeof(tempstring), "IPV4_AS_TEXT%s=%s", embeddedipv4string, as_text);
+		if (as_num32 != ASNUM_AS_UNKNOWN) {
+			if ( machinereadable != 0 ) {
+				snprintf(tempstring, sizeof(tempstring), "IPV4_AS_NUM%s=%d", embeddedipv4string, as_num32);
 				printout(tempstring);
+
+				if (as_text != NULL) {
+					snprintf(tempstring, sizeof(tempstring), "IPV4_AS_TEXT%s=%s", embeddedipv4string, as_text);
+					printout(tempstring);
+				};
+			} else {
+				if (as_text != NULL) {
+					fprintf(stdout, "Autonomous System Information: %s\n", as_text);
+				} else {
+					fprintf(stdout, "Autonomous System Number (32-bit): %d\n", as_num32);
+				};
 			};
 		} else {
-			if (as_text != NULL) {
-				fprintf(stdout, "Autonomous System Information: %s\n", as_text);
-			} else {
-				fprintf(stdout, "Autonomous System Number (32-bit): %d\n", as_num32);
-			};
+			DEBUGPRINT_NA(DEBUG_showinfo, "Skip AS print: as_num32=ASNUM_AS_UNKNOWN");
 		};
-	} else {
-		DEBUGPRINT_NA(DEBUG_showinfo, "Skip AS print: as_num32=ASNUM_AS_UNKNOWN");
-	};
 
-	/* get CountryCode Information */
-	cc_index = libipv4addr_cc_index_by_addr(ipv4addrp);
+		/* get CountryCode Information */
+		cc_index = libipv4addr_cc_index_by_addr(ipv4addrp);
 
-	libipv6calc_db_wrapper_country_code_by_cc_index(tempstring2, sizeof(tempstring2),cc_index);
-	if ( machinereadable != 0 ) {
-		snprintf(tempstring, sizeof(tempstring), "IPV4_COUNTRYCODE%s=%s", embeddedipv4string, tempstring2);
-		printout(tempstring);
-	} else {
-		fprintf(stdout, "Country Code: %s\n", tempstring2);
+		libipv6calc_db_wrapper_country_code_by_cc_index(tempstring2, sizeof(tempstring2),cc_index);
+		if ( machinereadable != 0 ) {
+			snprintf(tempstring, sizeof(tempstring), "IPV4_COUNTRYCODE%s=%s", embeddedipv4string, tempstring2);
+			printout(tempstring);
+		} else {
+			fprintf(stdout, "Country Code: %s\n", tempstring2);
+		};
 	};
 
 
@@ -905,52 +887,54 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 		fprintf(stdout, "\n");
 	};
 
-	/* CountryCode */
-	DEBUGPRINT_NA(DEBUG_showinfo, "get country code");
-	cc_index = libipv6addr_cc_index_by_addr(ipv6addrp);
+	if ((typeinfo & (IPV6_NEW_ADDR_AGU)) != 0 ) {
+		/* CountryCode */
+		DEBUGPRINT_NA(DEBUG_showinfo, "get country code");
+		cc_index = libipv6addr_cc_index_by_addr(ipv6addrp);
 
-	if (cc_index > COUNTRYCODE_INDEX_MAX) {
-		if ( machinereadable != 0 ) {
-			fprintf(stderr, "Error getting CountryCode for IPv6 address\n");
-		};
-	} else {
-		libipv6calc_db_wrapper_country_code_by_cc_index(tempstring2, sizeof(tempstring2),cc_index);
-		if ( machinereadable != 0 ) {
-			snprintf(tempstring, sizeof(tempstring), "IPV6_COUNTRYCODE=%s" , tempstring2);
-			printout(tempstring);
-		} else {
-			fprintf(stdout, "Country Code: %s\n", tempstring2);
-		};
-	};
-
-	/* AS */
-	DEBUGPRINT_NA(DEBUG_showinfo, "get AS number/text");
-	if ((typeinfo & IPV6_ADDR_ANONYMIZED_PREFIX) == 0) {
-		if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_AS) == 1) {
-			as_text = libipv6calc_db_wrapper_as_text_by_addr(ipv6addrstring, 6);
-		};
-	};
-
-	as_num32 = libipv6addr_as_num32_by_addr(ipv6addrp);
-
-	if ((as_num32 == 0) && (machinereadable == 0)) {
-		fprintf(stderr, "Error getting AS number from anonymized IPv6 address\n");
-	} else {
-		if ( machinereadable != 0 ) {
-			if (as_num32 == 0) {
-				snprintf(tempstring, sizeof(tempstring), "IPV6_AS_NUM=(unknown)");
-			} else {
-				snprintf(tempstring, sizeof(tempstring), "IPV6_AS_NUM=%d", as_num32);
+		if (cc_index > COUNTRYCODE_INDEX_MAX) {
+			if ( machinereadable != 0 ) {
+				fprintf(stderr, "Error getting CountryCode for IPv6 address\n");
 			};
-			printout(tempstring);
-
-			if (as_text != NULL) {
-				snprintf(tempstring, sizeof(tempstring), "IPV6_AS_TEXT=%s", as_text);
+		} else {
+			libipv6calc_db_wrapper_country_code_by_cc_index(tempstring2, sizeof(tempstring2),cc_index);
+			if ( machinereadable != 0 ) {
+				snprintf(tempstring, sizeof(tempstring), "IPV6_COUNTRYCODE=%s" , tempstring2);
 				printout(tempstring);
+			} else {
+				fprintf(stdout, "Country Code: %s\n", tempstring2);
 			};
+		};
 
+		/* AS */
+		DEBUGPRINT_NA(DEBUG_showinfo, "get AS number/text");
+		if ((typeinfo & IPV6_ADDR_ANONYMIZED_PREFIX) == 0) {
+			if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_AS) == 1) {
+				as_text = libipv6calc_db_wrapper_as_text_by_addr(ipv6addrstring, 6);
+			};
+		};
+
+		as_num32 = libipv6addr_as_num32_by_addr(ipv6addrp);
+
+		if ((as_num32 == 0) && (machinereadable == 0)) {
+			fprintf(stderr, "Error getting AS number from IPv6 address\n");
 		} else {
-			fprintf(stdout, "ASN for address: %d\n", as_num32);
+			if ( machinereadable != 0 ) {
+				if (as_num32 == 0) {
+					snprintf(tempstring, sizeof(tempstring), "IPV6_AS_NUM=(unknown)");
+				} else {
+					snprintf(tempstring, sizeof(tempstring), "IPV6_AS_NUM=%d", as_num32);
+				};
+				printout(tempstring);
+
+				if (as_text != NULL) {
+					snprintf(tempstring, sizeof(tempstring), "IPV6_AS_TEXT=%s", as_text);
+					printout(tempstring);
+				};
+
+			} else {
+				fprintf(stdout, "ASN for address: %d\n", as_num32);
+			};
 		};
 	};
 
@@ -976,7 +960,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 
 	/* 6to4 */
 	if ( (typeinfo & IPV6_NEW_ADDR_6TO4) != 0 ) {
-		r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, 1);
+		r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 
 		if (r == 0) {
 			retval = libipv4addr_ipv4addrstruct_to_string(&ipv4addr, helpstring, sizeof(helpstring), 0);
@@ -1004,10 +988,10 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	/* Teredo */
 	if ( (typeinfo & IPV6_NEW_ADDR_TEREDO) != 0 ) {
 		/* extract Teredo client IPv4 address */
-		r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, 1);
+		r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 
 		if (r == 0) {
-			r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr2, 2);
+			r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr2, IPV6_ADDR_SELECT_IPV4_TEREDO_SERVER);
 
 			if (r == 0) {
 				print_ipv4addr(&ipv4addr, formatoptions | FORMATOPTION_printembedded, "TEREDO-CLIENT");
@@ -1042,7 +1026,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	};
 
 	if ( (typeinfo & IPV6_NEW_ADDR_NAT64) != 0 )  {
-		r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, 0);
+		r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 
 		if (r == 0) {
 			if ( machinereadable != 0 ) {
@@ -1080,7 +1064,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	
 	/* Compat or mapped */
 	if ( (typeinfo & (IPV6_ADDR_COMPATv4 | IPV6_ADDR_MAPPED)) != 0 ) {
-		r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, 0);
+		r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 
 		if (r == 0) {
 			if ( machinereadable != 0 ) {
