@@ -2,8 +2,8 @@
 #
 # Project    : ipv6calc
 # File       : test_showinfo.sh
-# Version    : $Id: test_showinfo.sh,v 1.35 2014/04/25 05:48:13 ds6peter Exp $
-# Copyright  : 2002-2011 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: test_showinfo.sh,v 1.38 2014/07/29 18:54:06 ds6peter Exp $
+# Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc showinfo
 
@@ -101,12 +101,12 @@ if ./ipv6calc -v 2>&1 | grep -qw DB_IEEE; then
 fi
 
 ipv6calc_has_db_ipv4=0
-if ./ipv6calc -v 2>&1 | grep -qw DB_IPV4; then
+if ./ipv6calc -v 2>&1 | grep -qw DB_IPV4_REG; then
 	ipv6calc_has_db_ipv4=1
 fi
 
 ipv6calc_has_db_ipv6=0
-if ./ipv6calc -v 2>&1 | grep -qw DB_IPV6; then
+if ./ipv6calc -v 2>&1 | grep -qw DB_IPV6_REG; then
 	ipv6calc_has_db_ipv6=1
 fi
 
@@ -120,14 +120,14 @@ testscenarios_showinfo | while read address output; do
 
 	if echo "$output" | grep -q "^IPV4_REGISTRY="; then
 		if [ $ipv6calc_has_db_ipv4 -ne 1 ]; then
-			echo "Test: $address for $output SKIPPED (no DB_IPV4 compiled in)"
+			echo "Test: $address for $output SKIPPED (no DB_IPV4_REG compiled in)"
 			continue
 		fi
 	fi
 
 	if echo "$output" | grep -q "^IPV6_REGISTRY="; then
 		if [ $ipv6calc_has_db_ipv6 -ne 1 ]; then
-			echo "Test: $address for $output SKIPPED (no DB_IPV6 compiled in)"
+			echo "Test: $address for $output SKIPPED (no DB_IPV6_REG compiled in)"
 			continue
 		fi
 	fi
@@ -149,7 +149,7 @@ if [ "$1" = "minimal" ]; then
 	exit 0
 fi
 
-if ./ipv6calc -v 2>&1 | grep -qw GeoIP; then
+if ./ipv6calc -q -v 2>&1 | grep -qw GeoIP; then
 	echo "Run GeoIP tests"
 	getexamples_GeoIP | while read address; do
 		echo "Run GeoIP showinfo on: $address"
@@ -157,7 +157,7 @@ if ./ipv6calc -v 2>&1 | grep -qw GeoIP; then
 			true
 		else
 			if echo "$address" | grep -q ":"; then
-				if ./ipv6calc -v 2>&1 | grep -v -q "GeoIPv6"; then
+				if ./ipv6calc -q -v 2>&1 | grep -v -q "GeoIPv6"; then
 					echo "Expected result (missing GEOIP) because of missing IPv6 support in GeoIP)"
 					true
 				else
@@ -205,7 +205,7 @@ else
 	echo "GeoIP tests skipped"
 fi
 
-if ./ipv6calc -v 2>&1 | grep -qw IP2Location; then
+if ./ipv6calc -q -v 2>&1 | grep -qw IP2Location; then
 	echo "Run IP2Location tests"
 	getexamples_IP2Location | while read address; do
 		echo "Run IP2Location showinfo on: $address"
