@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calchelp.c
- * Version    : $Id: ipv6calchelp.c,v 1.57 2014/05/11 09:49:38 ds6peter Exp $
+ * Version    : $Id: ipv6calchelp.c,v 1.64 2014/08/02 06:45:14 ds6peter Exp $
  * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -293,29 +293,43 @@ void printhelp_actiontypes(const uint32_t formatoptions, const struct option lon
 
 
 /* print global common help */
-void printhelp_common(void) {
+void printhelp_common(const uint32_t help_features) {
+	fprintf(stderr, "\n");
+
 	fprintf(stderr, "  [-d|--debug <debug value>] : debug value (bitwise like)\n");
 	fprintf(stderr, "                                can also be set by IPV6CALC_DEBUG environment value\n");
-	fprintf(stderr, "  [-v|--version [-v [-v]]]   : version information (2 optional verbose levels)\n");
+	fprintf(stderr, "  [-v|--version [-v [-v]]]   : version information (2 optional detail levels)\n");
+	fprintf(stderr, "  [-v|--version -h]          : explanation of feature tokens\n");
+	fprintf(stderr, "  [-V|--verbose]             : be more verbose\n");
 	fprintf(stderr, "  [-h|--help|-?]             : this online help\n");
 
-#ifdef SUPPORT_IP2LOCATION
-	fprintf(stderr, "\n");
-	fprintf(stderr, "  [--db-ip2location-disable        ] : IP2Location support disabled\n");
-	fprintf(stderr, "  [--db-ip2location-dir <directory>] : IP2Location database directory (default: %s)\n", ip2location_db_dir);
-#ifdef SUPPORT_IP2LOCATION_DYN
-	fprintf(stderr, "  [--db-ip2location-lib <file>]      : IP2Location library file (default: %s)\n", ip2location_lib_file);
-#endif
-#endif
+	if ((help_features & IPV6CALC_HELP_QUIET) != 0) {
+		fprintf(stderr, "  [-q|--quiet]               : be more quiet\n");
+	};
 
+	if ((help_features & IPV6CALC_HELP_IP2LOCATION) != 0) {
+#ifdef SUPPORT_IP2LOCATION
+		fprintf(stderr, "\n");
+		fprintf(stderr, "  [--db-ip2location-disable        ] : IP2Location support disabled\n");
+		fprintf(stderr, "  [--db-ip2location-dir <directory>] : IP2Location database directory (default: %s)\n", ip2location_db_dir);
+#ifdef SUPPORT_IP2LOCATION_DYN
+		fprintf(stderr, "  [--db-ip2location-lib <file>     ] : IP2Location library file (default: %s)\n", ip2location_lib_file);
+#endif
+#endif
+	};
+
+	if ((help_features & IPV6CALC_HELP_GEOIP) != 0) {
 #ifdef SUPPORT_GEOIP
-	fprintf(stderr, "\n");
-	fprintf(stderr, "  [--db-geoip-disable              ] : GeoIP support disabled\n");
-	fprintf(stderr, "  [--db-geoip-dir       <directory>] : GeoIP database directory (default: %s)\n", geoip_db_dir);
+		fprintf(stderr, "\n");
+		fprintf(stderr, "  [--db-geoip-disable              ] : GeoIP support disabled\n");
+		fprintf(stderr, "  [--db-geoip-dir       <directory>] : GeoIP database directory (default: %s)\n", geoip_db_dir);
 #ifdef SUPPORT_GEOIP_DYN
-	fprintf(stderr, "  [--db-geoip-lib       <file>]      : GeoIP library file (default: %s)\n", geoip_lib_file);
+		fprintf(stderr, "  [--db-geoip-lib       <file>     ] : GeoIP library file (default: %s)\n", geoip_lib_file);
 #endif
 #endif
+	};
+
+	fprintf(stderr, "\n");
 	return;
 };
 
@@ -689,36 +703,20 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 
 
 /***************************
- * version information
+ * verbose feature information
  * *************************/
 
-void ipv6calc_print_features(void) {
-#ifdef SUPPORT_IP2LOCATION
-	fprintf(stderr, " IP2Location");
-#endif
-#ifdef SUPPORT_GEOIP
-	fprintf(stderr, " GeoIP");
-#ifdef SUPPORT_GEOIP_V6
-	fprintf(stderr, " GeoIPv6");
-#endif
-#endif
-#ifdef SUPPORT_DB_IEEE
-	fprintf(stderr, " DB_IEEE");
-#endif
-#ifdef SUPPORT_DB_IPV4
-	fprintf(stderr, " DB_IPV4");
-#endif
-#ifdef SUPPORT_DB_IPV6
-	fprintf(stderr, " DB_IPV6");
-#endif
-};
-
-
 /* display features in verbose mode */
 void ipv6calc_print_features_verbose(const int level_verbose) {
-	char string[NI_MAXHOST];
+	char string[NI_MAXHOST] = "";
+
+	libipv6calc_db_wrapper_capabilities(string, sizeof(string));
+	fprintf(stderr, "Capabilities: %s\n\n", string);
 
 #ifdef SUPPORT_GEOIP
+#ifdef GEOIP_INCLUDE_VERSION
+	fprintf(stderr, "GeoIP support enabled, compiled with include file version: %s\n", GEOIP_INCLUDE_VERSION);
+#endif
 #ifndef SUPPORT_GEOIP_DYN
 #ifdef SUPPORT_GEOIP_V6
 #if defined (SUPPORT_GEOIP_COUNTRY_CODE_BY_ADDR_V6) && defined (SUPPORT_GEOIP_COUNTRY_NAME_BY_ADDR_V6)
@@ -726,9 +724,9 @@ void ipv6calc_print_features_verbose(const int level_verbose) {
 #else
 	fprintf(stderr, "GeoIP support enabled, compiled with IPv4 & IPv6 support (in compatibility mode)\n");
 #endif
-#else
+#else // SUPPORT_GEOIP_V6
 	fprintf(stderr, "GeoIP support enabled, compiled with IPv4 support only\n");
-#endif
+#endif // SUPPORT_GEOIP_V6
 #ifdef SUPPORT_GEOIP_LIB_VERSION
 	fprintf(stderr, "GeoIP dynamic library version (on this system): %s\n", libipv6calc_db_wrapper_GeoIP_lib_version());
 #else
@@ -737,28 +735,31 @@ void ipv6calc_print_features_verbose(const int level_verbose) {
 #else // SUPPORT_GEOIP_DYN
 #ifdef SUPPORT_GEOIP_V6
 	fprintf(stderr, "GeoIP support by dynamic library load, compiled with IPv4 & IPv6 support\n");
-#else
+#else  // SUPPORT_GEOIP_V6
 	fprintf(stderr, "GeoIP support by dynamic library load, compiled with IPv4 support only\n");
+#endif // SUPPORT_GEOIP_V6
+	fprintf(stderr, "GeoIP configured dynamic library file and detected version: %s %s\n", geoip_lib_file, libipv6calc_db_wrapper_GeoIP_lib_version());
 #endif // SUPPORT_GEOIP_DYN
-	fprintf(stderr, "GeoIP configured dynamic library file and version: %s %s\n", geoip_lib_file, libipv6calc_db_wrapper_GeoIP_lib_version());
-#endif
 
 	//TODO: list of GeoIP files
 #ifdef SUPPORT_GEOIP_V6
 	//TODO: list of GeoIP files
 #endif
 	libipv6calc_db_wrapper_GeoIP_wrapper_info(string, sizeof(string));
-	fprintf(stderr, "%s\n", string);
+	fprintf(stderr, "%s\n\n", string);
 #else
-	fprintf(stderr, "GeoIP support not enabled\n");
+	fprintf(stderr, "GeoIP support not compiled-in\n\n");
 #endif
 
 #ifdef SUPPORT_IP2LOCATION
-#ifndef SUPPORT_IP2LOCATION_DYN
+#ifdef GEOIP_INCLUDE_VERSION
+	fprintf(stderr, "IP2Location support enabled, compiled with include file version: %s\n", IP2LOCATION_INCLUDE_VERSION);
+#endif
 	fprintf(stderr, "IP2Location support enabled, compiled with API version: %s\n", xmakestr(API_VERSION));
+#ifndef SUPPORT_IP2LOCATION_DYN
 #else
 	fprintf(stderr, "IP2Location support by dynamic library load\n");
-	fprintf(stderr, "IP2Location configured dynamic library file and version: %s %s\n", ip2location_lib_file, libipv6calc_db_wrapper_IP2Location_lib_version());
+	fprintf(stderr, "IP2Location configured dynamic library file and detected version: %s %s\n", ip2location_lib_file, libipv6calc_db_wrapper_IP2Location_lib_version());
 #endif
 	// TODO: show base directory
 	/*
@@ -773,15 +774,17 @@ void ipv6calc_print_features_verbose(const int level_verbose) {
 		fprintf(stderr, "IP2Location IPv6 default file: not configured\n");
 	};
 	*/
+	libipv6calc_db_wrapper_IP2Location_wrapper_info(string, sizeof(string));
+	fprintf(stderr, "%s\n\n", string);
 #else
-	fprintf(stderr, "IP2Location support not enabled\n");
+	fprintf(stderr, "IP2Location support not compiled-in\n\n");
 #endif
 
 #ifdef SUPPORT_BUILTIN
 	libipv6calc_db_wrapper_BuiltIn_wrapper_info(string, sizeof(string));
-	fprintf(stderr, "%s\n", string);
+	fprintf(stderr, "%s\n\n", string);
 #else
-	fprintf(stderr, "BuiltIn support not enabled\n");
+	fprintf(stderr, "BuiltIn support not compiled-in\n\n");
 #endif
 
 	libipv6calc_db_wrapper_print_db_info(level_verbose, "");
