@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calchelp.h
- * Version    : $Id: ipv6calchelp.h,v 1.17 2014/04/02 06:11:55 ds6peter Exp $
+ * Version    : $Id: ipv6calchelp.h,v 1.19 2014/07/22 06:00:41 ds6peter Exp $
  * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -11,6 +11,18 @@
 #include "ipv6calc_inttypes.h"
 #include "ipv6calcoptions.h"
 
+#ifndef _ipv6calchelp_h
+
+#define _ipv6calchelp_h 1
+
+#define IPV6CALC_HELP_GEOIP		0x0010
+#define IPV6CALC_HELP_IP2LOCATION	0x0100
+#define IPV6CALC_HELP_ALL		0xffff
+#define IPV6CALC_HELP_BASIC		0x0000
+#define IPV6CALC_HELP_QUIET		0x0001
+
+#endif
+
 /* defined in each main program */
 extern void printhelp_info(void);
 extern void printhelp_copyright(void);
@@ -27,10 +39,9 @@ extern void printhelp_missinginputdata(void);
 extern void printhelp_inputtypes(const uint32_t formatoptions);
 extern void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoptions);
 extern void printhelp_actiontypes(const uint32_t formatoptions, const struct option longopts[]);
-extern void printhelp_common(void);
+extern void printhelp_common(const uint32_t help_features);
 extern void printhelp_shortcut_options(const struct option longopts[], const s_ipv6calc_longopts_shortopts_map longopts_shortopts_map[]);
 extern void printhelp_output_dispatcher(const uint32_t outputtype);
 extern void printhelp_action_dispatcher(const uint32_t action, const int embedded);
 
-extern void ipv6calc_print_features(void);
 extern void ipv6calc_print_features_verbose(const int level_vebose);
