@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : libipv6addr.c
- * Version    : $Id: libipv6addr.c,v 1.108 2014/05/11 09:49:38 ds6peter Exp $
+ * Version    : $Id: libipv6addr.c,v 1.112 2014/07/22 06:00:41 ds6peter Exp $
  * Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  *
  * Information:
@@ -807,7 +807,7 @@ uint32_t ipv6addr_gettype(const ipv6calc_ipv6addr *ipv6addrp) {
 		ipv6addr_copy(&ipv6addr, ipv6addrp);
 		ipv6addr.scope = type; // store what we already have
 
-		r = libipv6addr_get_included_ipv4addr(&ipv6addr, &ipv4addr, 1);
+		r = libipv6addr_get_included_ipv4addr(&ipv6addr, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 		if (r == 0) {
 			if ((ipv4addr.scope & IPV4_ADDR_ANONYMIZED) != 0) {
 				if ((type & IPV6_ADDR_HAS_PUBLIC_IPV4_IN_PREFIX) != 0) {
@@ -823,7 +823,7 @@ uint32_t ipv6addr_gettype(const ipv6calc_ipv6addr *ipv6addrp) {
 		ipv6addr_copy(&ipv6addr, ipv6addrp);
 		ipv6addr.scope = type; // store what we already have
 
-		r = libipv6addr_get_included_ipv4addr(&ipv6addr, &ipv4addr, 1);
+		r = libipv6addr_get_included_ipv4addr(&ipv6addr, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 		if (r == 0) {
 			if ((ipv4addr.scope & IPV4_ADDR_ANONYMIZED) != 0) {
 				type |= IPV6_ADDR_ANONYMIZED_IID;
@@ -834,7 +834,7 @@ uint32_t ipv6addr_gettype(const ipv6calc_ipv6addr *ipv6addrp) {
 		ipv6addr_copy(&ipv6addr, ipv6addrp);
 		ipv6addr.scope = type; // store what we already have
 
-		r = libipv6addr_get_included_ipv4addr(&ipv6addr, &ipv4addr, 2);
+		r = libipv6addr_get_included_ipv4addr(&ipv6addr, &ipv4addr, IPV6_ADDR_SELECT_IPV4_TEREDO_SERVER);
 		if (r == 0) {
 			if ((ipv4addr.scope & IPV4_ADDR_ANONYMIZED) != 0) {
 				type |= IPV6_ADDR_ANONYMIZED_PREFIX;
@@ -1112,8 +1112,13 @@ int addr_to_ipv6addrstruct(const char *addrstring, char *resultstring, const siz
 
 	DEBUGPRINT_WA(DEBUG_libipv6addr, "Got input '%s'", addrstring);
 
+	if (strlen(addrstring) < 2) {
+		fprintf(stderr, "Error in given IPv6 address, has less than 2 chars!\n");
+		return (1);
+	};
+
 	if (strlen(addrstring) >= sizeof(tempstring)) {
-		fprintf(stderr, "Input too long: %s\n", addrstring);
+		fprintf(stderr, "Error in given IPv6 address, has too much chars: %s\n", addrstring);
 		return (1);
 	};
 
@@ -1240,7 +1245,7 @@ int addr_to_ipv6addrstruct(const char *addrstring, char *resultstring, const siz
 		/* check compat */
 		for ( i = 0; i <= 3; i++ ) {
 			if ( compat[i] > 255 )	{
-				snprintf(resultstring, resultstring_length, "Error, given compatv4/mapped address '%s' is not valid on position %d!", addrstring, i);
+				snprintf(resultstring, resultstring_length, "Error in given compatv4/mapped IPv6 address, '%s' is not valid on position %d!", addrstring, i);
 				retval = 1;
 				return (retval);
 			};
@@ -1257,7 +1262,7 @@ int addr_to_ipv6addrstruct(const char *addrstring, char *resultstring, const siz
 	DEBUGPRINT_WA(DEBUG_libipv6addr, "reading into array, got items: %d", result);
 
 	if ( result != expecteditems ) {
-		snprintf(resultstring, resultstring_length, "Error splitting address %s, got %d items instead of %d!", addronlystring, result, expecteditems);
+		snprintf(resultstring, resultstring_length, "Error in given IPv6 address, splitting of '%s' returns %d items instead of %d!", addronlystring, result, expecteditems);
 		retval = 1;
 		return (retval);
 	};
@@ -1265,7 +1270,7 @@ int addr_to_ipv6addrstruct(const char *addrstring, char *resultstring, const siz
 	/* check address words range */
 	for ( i = 0; i <= 7; i++ ) {
 		if ( (temp[i] < 0) || (temp[i] > 0xffff) )	{
-			snprintf(resultstring, resultstring_length, "Error, given address '%s' is not valid on position %d!", addronlystring, i);
+			snprintf(resultstring, resultstring_length, "Error in given IPv6 address, '%s' is not valid on position %d!", addronlystring, i);
 			retval = 1;
 			return (retval);
 		};
@@ -2548,7 +2553,9 @@ int ipv6addr_filter(const ipv6calc_ipv6addr *ipv6addrp, const s_ipv6calc_filter_
 
 /* get included IPv4 address from an IPv6 address */
 /* in:	IPv6 address pointer (ro)
- *	selector: in case of Teredo: 1=client 2=server
+ *	selector: in case of Teredo (otherwise ignored):
+ *	 IPV6_ADDR_SELECT_IPV4_DEFAULT (TEREDO_CLIENT)
+ *	 IPV6_ADDR_SELECT_IPV4_TEREDO_SERVER
  * mod:	IPv4 address pointer (rw)
  * ret: 0=ok, !=0: no IPv4 adress included
  */
@@ -2566,14 +2573,15 @@ int libipv6addr_get_included_ipv4addr(const ipv6calc_ipv6addr *ipv6addrp, ipv6ca
 	if ((typeinfo & (IPV6_ADDR_COMPATv4 | IPV6_ADDR_MAPPED | IPV6_NEW_ADDR_NAT64)) != 0) {
 		begin = 12;
 	} else if ((typeinfo & IPV6_NEW_ADDR_TEREDO) != 0) {
-		if (selector == 1) {
+		if (selector == IPV6_ADDR_SELECT_IPV4_DEFAULT) {
 			// Teredo client
 			begin = 12;
 			xor   = 0xff;
-		} else if (selector == 2) {
+		} else if (selector == IPV6_ADDR_SELECT_IPV4_TEREDO_SERVER) {
+			// Teredo server
 			begin = 4;
 		} else {
-			fprintf(stderr, "libipv6addr_get_included_ipv4addr FAILED (unsupported value of selector: %d)", selector);
+			fprintf(stderr, "libipv6addr_get_included_ipv4addr FAILED (unsupported value of selector: %d - FIX CALLING CODE)", selector);
 		};
 	} else if ((typeinfo & IPV6_NEW_ADDR_6TO4) != 0) {
 		begin = 2;
@@ -2625,7 +2633,7 @@ uint16_t libipv6addr_cc_index_by_addr(const ipv6calc_ipv6addr *ipv6addrp) {
 			};
 		} else {
 			if ((ipv6addrp->scope & IPV6_NEW_ADDR_6TO4) != 0) {
-				retval = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, 0);
+				retval = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 				if (retval != 0) {
 					fprintf(stderr, "Error getting included IPv4 address from anonymized IPv6 address\n");
 					goto END_libipv6addr_cc_index_by_addr;
@@ -2635,7 +2643,7 @@ uint16_t libipv6addr_cc_index_by_addr(const ipv6calc_ipv6addr *ipv6addrp) {
 			};
 		};
 	} else if (((ipv6addrp->scope & IPV6_ADDR_ANONYMIZED_IID) != 0) && ((ipv6addrp->scope & IPV6_ADDR_HAS_PUBLIC_IPV4_IN_IID) != 0)) {
-		retval = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, 0);
+		retval = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 		if (retval != 0) {
 			fprintf(stderr, "Error getting included IPv4 address from anonymized IPv6 address\n");
 			goto END_libipv6addr_cc_index_by_addr;
@@ -2644,8 +2652,17 @@ uint16_t libipv6addr_cc_index_by_addr(const ipv6calc_ipv6addr *ipv6addrp) {
 		cc_index = libipv4addr_cc_index_by_addr(&ipv4addr);
 	} else {
 		if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_CC) == 1) {
-			if ((ipv6addrp->scope & IPV6_NEW_ADDR_NAT64) != 0) {
-				retval = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, 0);
+			if ((ipv6addrp->scope & IPV6_ADDR_HAS_PUBLIC_IPV4_IN_IID) != 0) {
+				/* retrieve CountryCodeIndex from IPv4 address inside */
+				retval = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
+				if (retval != 0) {
+					fprintf(stderr, "Error getting included IPv4 address from IPv6 address\n");
+					goto END_libipv6addr_cc_index_by_addr;
+				};
+
+				cc_index = libipv4addr_cc_index_by_addr(&ipv4addr);
+			} else if ((ipv6addrp->scope & IPV6_ADDR_HAS_PUBLIC_IPV4_IN_PREFIX) != 0) {
+				retval = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 				if (retval != 0) {
 					fprintf(stderr, "Error getting included IPv4 address from IPv6 address\n");
 					goto END_libipv6addr_cc_index_by_addr;
@@ -2694,7 +2711,7 @@ uint32_t libipv6addr_as_num32_by_addr(const ipv6calc_ipv6addr *ipv6addrp) {
 			};
 		} else {
 			if ((ipv6addrp->scope & IPV6_NEW_ADDR_6TO4) != 0) {
-				retval = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, 0);
+				retval = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 				if (retval != 0) {
 					fprintf(stderr, "Error getting included IPv4 address from anonymized IPv6 address\n");
 					goto END_libipv6addr_as_num32_by_addr;
